@@ -354,5 +354,4 @@ PostScript text to be executed in that process."
   )
 
 ;; XEmacs addition
-;;;###autoload
-(add-to-list 'auto-mode-alist '("\\.c?ps\\'" . postscript-mode))
+;;;###autoload(add-to-list 'auto-mode-alist '("\\.c?ps\\'" . postscript-mode))
